<?php
    session_start();
    error_reporting(E_ALL);
    ini_set('display_errors', 1);
    
    require_once '../php/database.php'; 
    require_once '../php/function.php'; 
    
    //check login 
    if (!isset($_SESSION['user_id'])) 
    {
        header("Location: ../index.php");
        exit();
    }
    $user = new User($pdo, $_SESSION['user_id']);
    $dashboard = new Dashboard($user); 

    $stmt = $pdo->query("SELECT id, name FROM countries ORDER BY name ASC");
    $countries = $stmt->fetchAll(PDO::FETCH_ASSOC);
    $permissions = $user->get_permissions();

    if (!in_array('add_customer', $permissions)) {
        header("Location: ../index.php");
        exit();
    }
    
    $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
    
    //get the language from url 
    if (isset($_GET['lang'])) {
        $_SESSION['lang'] = $_GET['lang'];
    }
    
    //englsh is the defult language
    $lang = $_SESSION['lang'] ?? 'en'; 
    
    //get language from session
    $lang = $_SESSION['lang'] ?? 'en'; // دریافت زبان از سشن

//echo "<h1>" . translate('dashboard', $lang) . "</h1>";
//echo "<p>" . translate('register_new_customer', $lang) . "</p>";

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?=translate('dashboard', $lang);?></title>
    <link rel="stylesheet" href="../assets/css/animate.min.css"/>
    <link rel="stylesheet" href="../assets/css/all.min.css"/>
    <link href="../assets/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../assets/css/style.css?v=1.1" />
    <style>
    

        .success {
            color: green;
            background-color: #d4edda;
            padding: 10px;
            border: 1px solid #c3e6cb;
            border-radius: 5px;
            margin-bottom: 15px;
        }
        .error {
            color: red;
            background-color: #f8d7da;
            padding: 10px;
            border: 1px solid #f5c6cb;
            border-radius: 5px;
            margin-bottom: 15px;
        }
    </style>
</head>
<body>
    <!-- Main content -->
    <div class="d-flex">
        <?php include("../admin/side_bar.php"); ?>
        <div class="container animate__animated animate__fadeIn mt-5 ">
            <div class="row">
                <div class="col-md-12">
                    <?php
                        if (isset($_SESSION['message'])) 
                        {
                            echo "<div id='message' class='{$_SESSION['message_type']}'>" . $_SESSION['message'] . "</div>";
                            unset($_SESSION['message']);
                            unset($_SESSION['message_type']);
                        }?>
                    <div class="aside-form">
                        <h4 class="text-center" style="font-weight:bold;color:#7a5fff"><?=translate('Add Customer', $lang);?></h4>
                        <form action="../php/process.php" method="POST" class="mt-5">
                            <input type="hidden" name="csrf_token" value="<?= $_SESSION['csrf_token']; ?>">
                            <input type="hidden" name="status" value="draft"> 
                            <div class="mb-3">
                                <label for="name" class="form-label"><?=translate('Company/Individual Name', $lang);?></label>
                                <input type="text" pattern="[A-Za-z ]+" title="Only English letters and spaces are allowed" class="form-control" id="name" name="name" required>
                            </div>
    
                            <div class="mb-3">
                                <label for="legal_entity_type" class="form-label"><?=translate('Legal Entity Type', $lang);?></label>
                                <select class="form-control" id="legal_entity_type" name="legal_entity_type" required>
                                    <option value="Corporate"><?=translate('Corporate', $lang);?></option>
                                    <option value="Individual"><?=translate('Individual', $lang);?></option>
                                </select>
                            </div>
    
                            <div class="mb-3">
                                <label for="Industry" class="form-label"><?=translate('Industry', $lang);?></label>
                                <input type="text" class="form-control" pattern="[A-Za-z ]+" id="industry" name="Industry" required>
                            </div>
    
                            <div class="mb-3">
                                <label for="country" class="form-label"><?=translate('country', $lang);?></label>
                                <select class="form-control" id="country" name="country" required>
                                    <option value="">Select Country</option>
                                    <?php foreach ($countries as $country): ?>
                                        <option value="<?php echo $country['id']; ?>"><?php echo htmlspecialchars($country['name']); ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
    
                            <div class="mb-3">
                                <label for="city" class="form-label"><?=translate('City', $lang);?></label>
                                <select class="form-control" id="city" name="city" required>
                                    <option value="">Select City</option>
                                </select>
                            </div>
    
                            <div class="mb-3">
                                <label for="address" class="form-label"><?=translate('Address', $lang);?></label>
                                <input type="text" class="form-control" pattern="[A-Za-z ]+" id="address" name="address" required>
                            </div>
    
                            <div class="mb-3">
                                <label for="phone_number" class="form-label"><?=translate('Phone Number', $lang);?></label>
                                <div class="phone-field">
                                    <input type="text" name="phone_number[]" id="phone_number"  class="phone-input form-control" placeholder="">
                                </div>
                                <div id="phone-container"></div>
                                <button class="btn" type="button" id="add-phone">+ <?=translate('Add Phone Number', $lang);?> </button>
                            </div>
    
                            <div class="mb-3">
                                <label for="email" class="form-label"><?=translate('Email', $lang);?> </label>
                                <input type="email" class="form-control" id="email" name="email" required>
                            </div>
    
                            <button value="1" type="submit" name="add_customer" class="btn login-btn "><?=translate('Add Customer', $lang);?></button>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        //add phone number input 
        document.getElementById("add-phone").addEventListener("click", function () {
            let container = document.getElementById("phone-container");
            let newInput = document.createElement("div");
            newInput.classList.add("phone-field");
    
            //hide new input
            newInput.style.opacity = "0";
            newInput.style.transform = "translateY(-20px)";
            newInput.style.transition = "opacity 0.5s ease-out, transform 0.5s ease-out";
    
            newInput.innerHTML = `
                <input type="text" name="phone_number[]" id="phone_number"  class="phone-input form-control mt-2" placeholder="">
                <button type="button" class="remove-phone btn btn-danger btn-sm mt-2 ms-2">❌</button>
            `;
    
            //hide button
            this.style.opacity = "0"; 
            this.style.transition = "opacity 0.5s ease-out"; 
            setTimeout(() => {
                this.style.opacity = "1"; 
            }, 500); 
        
            //add container to form 
            container.appendChild(newInput);
        
            setTimeout(() => {
                newInput.style.opacity = "1";
                newInput.style.transform = "translateY(0)";
            }, 10);
        });
    
        //delete phone numbers
        document.addEventListener("click", function (e) {
            if (e.target.classList.contains("remove-phone")) {
                let phoneField = e.target.parentElement;
                phoneField.style.opacity = "0";
                phoneField.style.transform = "translateY(-10px)";
                setTimeout(() => {
                    phoneField.remove();
                }, 300); 
            }
        });
        //show contries
        $(document).ready(function () {
            $('#country').change(function () {
                var country_id = $(this).val();
                if (country_id != "") {
                    $.ajax({
                        url: 'get_cities.php',
                        method: 'POST',
                        data: { country_id: country_id },
                        success: function (response) {
                            $('#city').html(response);
                        }
                    });
                } else {
                    $('#city').html('<option value="">Select City</option>');
                }
            });
        });
        
        //error and success alert
        window.onload = function() {
            var messageElement = document.getElementById('message');
            if (messageElement) {
                setTimeout(function() {
                    messageElement.style.display = 'none';
                }, 5000); 
            }
        }
    </script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
