<?php
    session_start();
    error_reporting(E_ALL);
    ini_set('display_errors', 1);

    //check login 
    if (!isset($_SESSION['user_id'])) 
    {
        header("Location: index.php");
        exit();
    }

    require_once 'database.php'; 
    require_once 'function.php';
    
    $user = new User($pdo, $_SESSION['user_id']); 
    $permissions = $user->get_permissions();
    
    if (is_array($permissions) && !empty($permissions)) 
    {
        $user_name = $_SESSION['username'] ?? "User";
        $user_role = $user->get_role();
        $user_permissions = $user->get_permissions();
        
        $query = $pdo->prepare("SELECT timezone FROM users WHERE user_id = :user_id");
        $query->execute(['user_id' => $_SESSION['user_id']]);
        $timezone = $query->fetchColumn();
        
        if ($timezone) 
        {
            date_default_timezone_set($timezone);
        }
        
        $hour = date('H');
        $greeting = ($hour < 12) ? "Good morning" : (($hour < 18) ? "Good afternoon" : "Good evening");

        $total_customers = 15;
        $total_orders = 8;
        $last_customer = "Ali from Tehran";
        $last_order = "#10345";
        $quotes = ["Success is not the key to happiness. Happiness is the key to success. – Albert Schweitzer",
            "The only way to do great work is to love what you do. – Steve Jobs",
            "Don’t watch the clock; do what it does. Keep going. – Sam Levenson"
        ];
        $quote = $quotes[array_rand($quotes)];
        $dashboard = new Dashboard($user); 
    } 
    else
    {
        header("Location: index.php");
        exit();
    }
?>
<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Dashboard</title>
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css"/>
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css"/>
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
        <link rel="stylesheet" href="assets/css/style.css" />
    </head>
    <body>
        <!-- Sidebar -->
        <div class="d-flex">
            <?php include("side_bar.php"); ?>
            <div class="dashboard-container animate__animated animate__fadeIn">
                <!--START WELCOME-->
                <div class="card shadow-lg p-4 text-center" style="background-color:#7a5fff; color:white;">
                    <h3><?php echo $greeting . ", " . $user_name; ?>! 👋</h3>
                    <p>Welcome to MAINSEN! Here you can manage your customers, track sales, and optimize your workflow.</p>
                </div>  
                <!--this section is for visitor-->
                <?php
                    if ($user_role == 'visitor') {
                ?>
                <div class="row mt-4">
                    <div class="col-md-6">
                        <div class="card p-3 shadow-sm">
                            <?php
                                $visitor_id = $_SESSION['user_id'];
                                $stmt = $pdo->prepare("SELECT COUNT(*) AS total_customers FROM customers WHERE created_by = ?");
                                $stmt->execute([$visitor_id]);
                                $row = $stmt->fetch(PDO::FETCH_ASSOC);
                                $total_customers = $row['total_customers'] ?? 0;
                            ?>
                            <h5><i class="fas fa-users"></i> Customers</h5>
                            <p><b><?php echo $total_customers; ?></b> registered customers.</p>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="card p-3 shadow-sm">
                            <h5><i class="fas fa-shopping-cart"></i> Orders</h5>
                            <p><b><?php echo $total_orders; ?></b> processed orders.</p>
                        </div>
                    </div>
                </div>
                <?php
                    }
                    if ($user_role == 'visitor') {?>
                <div class="card p-3 shadow-sm mt-4">
                    <h5>📅 Last Activity</h5>
                    <p>Last customer added: <b><?php echo $last_customer; ?></b> 🏢</p>
                    <p>Last order processed: <b><?php echo $last_order; ?></b> 🛒</p>
                </div>
                <?php } ?>
                <!--end visitor section-->
                <!--quote section-->
                <div class="quote-box mt-4 shadow-sm">
                    <i class="fas fa-quote-left"></i> <?php echo $quote; ?> <i class="fas fa-quote-right"></i>
                </div>
            </div>
        </div>
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    </body>
</html>