<?php
session_start();
error_reporting(E_ALL);
ini_set('display_errors', 1);

// بررسی لاگین
if (!isset($_SESSION['user_id'])) {
    echo "You are not logged in.";
    exit();
}

require_once '../php/database.php'; // اتصال به دیتابیس
require_once '../php/function.php'; // فرض بر این است که این فایل کلاسی برای دسترسی‌ها دارد

$user = new User($pdo, $_SESSION['user_id']); // ساخت شیء User

$dashboard = new Dashboard($user);  // ساخت شیء Dashboard با ارسال شیء User به سازنده آن
// دریافت لیست کشورها از دیتابیس
$stmt = $pdo->query("SELECT id, name FROM countries ORDER BY name ASC");
$countries = $stmt->fetchAll(PDO::FETCH_ASSOC);
$permissions = $user->get_permissions(); // گرفتن دسترسی‌ها از متد `get_permissions`

if (!in_array('add_customer', $permissions)) {
    echo "You do not have permission to add customers.";
    exit();
}

$successMessage = ''; // Initialize the variable
$user_id = $_SESSION['user_id'];
// دریافت مشتری‌های ثبت‌شده توسط این ویزیتور
$stmt = $pdo->prepare("
    SELECT 
        c.id, 
        c.name, 
        c.legal_entity_type, 
        c.industry, 
        COALESCE(countries.name, 'Unknown') AS country_name, 
        COALESCE(cities.name, 'Unknown') AS city_name, 
        c.address, 
        c.registration_date, 
        c.email, 
        c.website_url, 
        c.created_by,
        COALESCE(GROUP_CONCAT(cp.phone_number SEPARATOR ', '), 'Unknown') AS phone_numbers
    FROM draft_customers AS c
    LEFT JOIN countries ON c.country = countries.id
    LEFT JOIN cities ON c.city = cities.id
    LEFT JOIN customer_phone_numbers AS cp ON c.id = cp.customer_id
    WHERE c.created_by = ?  -- مشخص کردن ویزیتور
    AND c.status = 'approved'  -- فقط رکوردهای تایید شده
    GROUP BY c.id;

");
$stmt->execute([$user_id]);
$customers = $stmt->fetchAll(PDO::FETCH_ASSOC);


$_SESSION['csrf_token'] = bin2hex(random_bytes(32));
//get the language from url 
    if (isset($_GET['lang'])) {
        $_SESSION['lang'] = $_GET['lang'];
    }
    
 //englsh is the defult language
    $lang = $_SESSION['lang'] ?? 'en'; 
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?=translate('dashboard', $lang);?></title>
    <link rel="stylesheet" href="../assets/css/animate.min.css"/>
    <link rel="stylesheet" href="../assets/css/all.min.css"/>
    <link href="../assets/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../assets/css/style.css?v=1.1" />
    <style>
    .container {
        padding-top: 30px;
    }

    h2 {
        font-size: 1.8rem;
        font-weight: bold;
        color: #333;
    }

    .table th, .table td {
        text-align: center;
        vertical-align: middle;
    }
    .btn-primary {
        background-color: #50216f;
        border: 1px solid #50216f;
    }

    .btn-primary:hover {
        background-color: #af8ec6;
        border-color: #af8ec6;
    }

</style>
</head>
<body>


<!-- Main content -->
<div class="d-flex">
    <?php include("../admin/side_bar.php"); ?>
    <div class="container animate__animated animate__fadeIn mt-5 ">
        <div class="row">
            <div class="col-md-12">
                
                <div class=" mt-5">
    <h2 class="mb-4" style="font-weight:bold;color:#7a5fff"><?=translate('Customer List', $lang);?></h2>
    <table class="table  table-bordered table-hover">
        <thead class="table-light">
            <tr>
                <th style="font-weight:bold;color:#50216f"><?=translate('Name', $lang);?></th>
                <th style="font-weight:bold;color:#50216f"><?=translate('Legal Entity Type', $lang);?></th>
                <th style="font-weight:bold;color:#50216f"><?=translate('Industry', $lang);?></th>
                <th style="font-weight:bold;color:#50216f"><?=translate('country', $lang);?></th>
                <th style="font-weight:bold;color:#50216f"><?=translate('City', $lang);?></th>
                <th style="font-weight:bold;color:#50216f"><?=translate('Address', $lang);?></th>
                <th style="font-weight:bold;color:#50216f"><?=translate('Registration Date', $lang);?></th>
                <th style="font-weight:bold;color:#50216f"><?=translate('Email', $lang);?></th>
                <th style="font-weight:bold;color:#50216f"><?=translate('Website URL', $lang);?></th>
                <th style="font-weight:bold;color:#50216f"><?=translate('Phone Number', $lang);?></th>
                <th style="font-weight:bold;color:#50216f"><?=translate('Actions', $lang);?></th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($customers as $customer): ?>
            <tr>
                <td><?= htmlspecialchars($customer['name']) ?></td>
<td><?= htmlspecialchars($customer['legal_entity_type']) ?></td>
<td><?= htmlspecialchars($customer['industry']) ?></td>
<td><?= htmlspecialchars($customer['country_name']) ?></td>
<td><?= htmlspecialchars($customer['city_name']) ?></td>
<td><?= htmlspecialchars($customer['address']) ?></td>
<td><?= htmlspecialchars(date('Y-m-d', strtotime($customer['registration_date']))) ?></td>

<td><?= htmlspecialchars($customer['email']) ?></td>
<td><?= htmlspecialchars($customer['website_url']) ?></td>
<td>
    <?= nl2br(htmlspecialchars(str_replace(',', "\n", $customer['phone_numbers']))) ?>
</td>

<td>
    <a href="edit_customer.php?id=<?= $customer['id'] ?>" class="btn btn-primary btn-sm">
        <i class="fas fa-edit"></i>
    </a>
</td>
  </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>
                
            </div>
        </div>
    </div>
</div>

<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script>
document.getElementById("add-phone").addEventListener("click", function () {
    let container = document.getElementById("phone-container");
    let newInput = document.createElement("div");
    newInput.classList.add("phone-field");

    // فرم جدید رو پنهان می‌کنیم
    newInput.style.opacity = "0";
    newInput.style.transform = "translateY(-20px)";
    newInput.style.transition = "opacity 0.5s ease-out, transform 0.5s ease-out";

    newInput.innerHTML = `
        <input type="text" name="phone_number[]" id="phone_number"  class="phone-input form-control mt-2" placeholder="">
        <button type="button" class="remove-phone btn btn-danger btn-sm mt-2 ms-2">❌</button>
    `;

    // ابتدا دکمه رو پنهان می‌کنیم
    this.style.opacity = "0"; // محو شدن دکمه
    this.style.transition = "opacity 0.5s ease-out"; // انیمیشن محو شدن دکمه
    setTimeout(() => {
        this.style.opacity = "1"; // دکمه بعد از انیمیشن دوباره ظاهر بشه
    }, 500); // 500 میلی‌ثانیه بعد از محو شدن دکمه

    // فرم رو به container اضافه می‌کنیم
    container.appendChild(newInput);

    // بعد از 500 میلی‌ثانیه (زمان انیمیشن فرم)، فرم رو به حالت قابل مشاهده میاریم
    setTimeout(() => {
        newInput.style.opacity = "1";
        newInput.style.transform = "translateY(0)";
    }, 10);
});

// حذف شماره‌ها با انیمیشن نرم
document.addEventListener("click", function (e) {
    if (e.target.classList.contains("remove-phone")) {
        let phoneField = e.target.parentElement;
        phoneField.style.opacity = "0";
        phoneField.style.transform = "translateY(-10px)";
        setTimeout(() => {
            phoneField.remove();
        }, 300); // 300 میلی‌ثانیه بعد از انیمیشن
    }
});



$(document).ready(function () {
    $('#country').change(function () {
        var country_id = $(this).val();
        if (country_id != "") {
            $.ajax({
                url: 'get_cities.php',
                method: 'POST',
                data: { country_id: country_id },
                success: function (response) {
                    $('#city').html(response);
                }
            });
        } else {
            $('#city').html('<option value="">Select City</option>');
        }
    });
});
<!-- اضافه کردن اسکریپت جاوا اسکریپت برای حذف پیام بعد از 5 ثانیه -->

    // بررسی وجود پیام در صفحه
    window.onload = function() {
        var messageElement = document.getElementById('message');
        
        // اگر پیغام وجود داشته باشد، بعد از 5 ثانیه آن را مخفی می‌کنیم
        if (messageElement) {
            setTimeout(function() {
                messageElement.style.display = 'none';
            }, 5000); // بعد از 5000 میلی‌ثانیه (5 ثانیه)
        }
    }

</script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
