<?php
    session_start();
    error_reporting(E_ALL);
ini_set('display_errors', 1);

    //check login 
    if (!isset($_SESSION['user_id'])) 
    {
        header("Location: index.php");
        exit();
    }

    require_once 'database.php'; 
    require_once 'function.php';
    
    $user = new User($pdo, $_SESSION['user_id']); 
    $permissions = $user->get_permissions();
    
    if (is_array($permissions) && !empty($permissions)) 
    {
        $user_name = $_SESSION['username'] ?? "User";
        $user_role = $user->get_role();
        $user_permissions = $user->get_permissions();
        
        $query = $pdo->prepare("SELECT timezone FROM users WHERE user_id = :user_id");
        $query->execute(['user_id' => $_SESSION['user_id']]);
        $timezone = $query->fetchColumn();
        
        if ($timezone) 
        {
            date_default_timezone_set($timezone);
        }
        
        $hour = date('H');
        $greeting = ($hour < 12) ? "Good morning" : (($hour < 18) ? "Good afternoon" : "Good evening");

        $total_customers = 15;
        $total_orders = 8;
        $last_customer = "Ali from Tehran";
        $last_order = "#10345";
        $quotes = ["Success is not the key to happiness. Happiness is the key to success.  Albert Schweitzer",
            "The only way to do great work is to love what you do.  Steve Jobs",
            "Dont watch the clock; do what it does. Keep going.  Sam Levenson"
        ];
        $quote = $quotes[array_rand($quotes)];
        $dashboard = new Dashboard($user); 
    } 
    else
    {
        header("Location: index.php");
        exit();
    }
?>
<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Dashboard</title>
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css"/>
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css"/>
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
        <link rel="stylesheet" href="assets/css/style.css" />
        <style>
/*            .table td, .table th {*/
/*    vertical-align: middle;*/
/*    text-align: center;*/
/*}*/

/*.notification {*/
/*    border: 1px solid #ccc;*/
/*    padding: 10px;*/
/*    margin-bottom: 10px;*/
/*    border-radius: 5px;*/
/*}*/

/*.notification a {*/
/*    margin: 0 5px;*/
/*}*/

        </style>
    </head>
    <body>
        <!-- Sidebar -->
        <div class="d-flex">
            <?php include("side_bar.php"); ?>
<div style="margin-top:10%;" class="container animate__animated animate__fadeIn">
<?php


// Fetch pending notifications for admin
$stmt = $pdo->query("SELECT n.id, n.message, c.name AS customer_name, c.legal_entity_type, c.industry, 
       c.country, c.city, c.address, GROUP_CONCAT(cp.phone_number ORDER BY cp.phone_number) AS phone_numbers, 
       c.email, c.registration_date, c.website_url, u.name AS visitor_name, 
       ci.name AS city_name, co.name AS country_name
FROM admin_notifications n
JOIN draft_customers c ON n.customer_id = c.id
JOIN users u ON c.created_by = u.user_id
LEFT JOIN cities ci ON c.city = ci.id
LEFT JOIN countries co ON c.country = co.id
LEFT JOIN customer_phone_numbers cp ON c.id = cp.customer_id
WHERE n.status = 'pending'
GROUP BY n.id, c.id, u.user_id, ci.id, co.id
ORDER BY n.created_at DESC
");
$notifications = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Display notifications in a table format
if($notifications) {
    echo "
    <div class=''>
            <table class='table table-bordered table-striped text-center align-middle'>
                <thead class='thead-dark'>
                    <tr>
                        <th>Customer Name</th>
                        <th>Visitor Name</th>
                        <th>Legal Entity Type</th>
                        <th>Industry</th>
                        <th>Country</th>
                        <th>City</th>
                        <th>Phone Numbers</th>
                        <th>Email</th>
                        <th>Registration Date</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                ";

    foreach ($notifications as $notification) :
        ?>
        
        <tr>
            <td><?=$notification['customer_name']?></td>
            <td><?=$notification['visitor_name']?></td>
                <td><?=$notification['legal_entity_type']?></td>
                <td><?=$notification['industry']?></td>
                <td><?=$notification['country_name']?></td>
                <td><?=$notification['city_name']?></td>
                <td>
                <?php
                if (!empty($notification['phone_numbers'])) {
                    $phone_numbers = explode(',', $notification['phone_numbers']);
                    foreach ($phone_numbers as $phone_number) {
                    ?>
                <p><?=$phone_number?></p>
                <?php
                }}
                ?>
                </td>
                <td><?=$notification['email']?></td>
                <td><?=$notification['registration_date']?></td>
                <td>
                    <a href='approve_customer.php?id=<?=$notification['id']?>' class='btn btn-success btn-sm'>Approve</a>
                    <a href='reject_customer.php?id=<?=$notification['id']?>' class='btn btn-danger btn-sm'>Reject</a>
                </td>
              </tr>
              <?php
    endforeach;

    echo "</tbody></table>";
} else {
    echo "<p>No pending notifications.</p>";
}
?>

</div>


                
                
            </div>
        </div>
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    </body>
</html>