<?php
session_start();
require_once('database.php'); 
require_once('function.php');  

error_reporting(E_ALL);
    ini_set('display_errors', 1);
if (!isset($pdo)) {
    die("ERROR!: Database is not connected. Call support.");
}

//user login
if ( isset($_POST['action']) && $_POST['action'] == 'login') 
{
    $username = trim($_POST['username']);
    $password = trim($_POST['password']);
    if (empty($username) || empty($password)) 
    {
        $_SESSION['error_message'] = "用户名和密码不能为空！";
        header("Location: ../index.php");
        exit();
    }
    //username exist in database
    $stmt = $pdo->prepare("SELECT user_id, name, password FROM users WHERE name = ?");
    $stmt->execute([$username]);
    $user = $stmt->fetch();
    if (!$user) 
    {
        $_SESSION['error_message'] = "用户名不正确！";
        header("Location: ../index.php");
        exit();
    }
    //check password
    if (!password_verify($password, $user['password'])) 
    {
        $_SESSION['error_message'] = "密码不正确！";        
        header("Location: ../index.php");
        exit();
    }
    //successful login 
    $_SESSION['user_id'] = $user['user_id'];
    $_SESSION['username'] = $user['name'];
    session_regenerate_id(true);
    header("Location: ../admin/dashboard.php");
    exit();
}

//add customer 
if (isset($_POST['add_customer']) && isset($_POST['csrf_token'])) 
{

    $name = $_POST['name'];
    $legal_entity_type = $_POST['legal_entity_type'];
    $industry = $_POST['industry'];
    $country = $_POST['country'];
    $city = $_POST['city'];
    $address = $_POST['address'];
    $phone_numbers = $_POST['phone_number']; 
    $email = $_POST['email'];
    $registration_date = date('Y-m-d H:i:s'); 
    $status = $_POST['status'];

    //check exist customer
    $stmt = $pdo->prepare("SELECT COUNT(*) FROM draft_customers WHERE name = ? AND legal_entity_type = ? AND country = ? AND city = ?");
    $stmt->execute([$name, $legal_entity_type, $country, $city]);
    $customerExists = $stmt->fetchColumn() > 0;

    if ($customerExists) {
        $_SESSION['message'] = "A customer with the same name, legal entity type, country, and city already exists!";
        $_SESSION['message_type'] = "error"; 
        header('Location: add_customer.php'); 
        exit();
    }

    //if the customer is new
    $stmt = $pdo->prepare("INSERT INTO draft_customers (name, legal_entity_type, industry, country, city, address, email, registration_date, created_by, csrf_token, status)
                           VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
    $stmt->execute([$name, $legal_entity_type, $industry, $country, $city, $address, $email, $registration_date, $_SESSION['user_id'], $_SESSION['csrf_token'], $status]);

    //get new customer ID
     $draft_customer_id = $pdo->lastInsertId();
     
    // Add notification for admin to review the customer
    $stmt = $pdo->prepare("INSERT INTO admin_notifications (customer_id, message, status)
                       VALUES (?, ?, ?)");
    $stmt->execute([$draft_customer_id, 'New customer added, awaiting admin approval.', 'pending']);
    //add phone numbers
    foreach ($phone_numbers as $phone) {
        if (!empty($phone)) {
            $stmt = $pdo->prepare("INSERT INTO customer_phone_numbers (customer_id, phone_number) VALUES (?, ?)");
            $stmt->execute([$draft_customer_id, $phone]);
        }
    }

    $_SESSION['message'] = "Customer has been saved as draft successfully!";
    $_SESSION['message_type'] = "success";
    header('Location: add_customer.php');
    exit();
}

//update customer
if (isset($_POST['update_customer'])) 
{
    $customer_id = $_POST['customer_id'];
    $name = $_POST['name'];
    $legal_entity_type = $_POST['legal_entity_type'];
    $industry = $_POST['industry'];
    $country_id = $_POST['country_name'];  
    $city_id = $_POST['city']; 
    $address = $_POST['address'];
    $phone_numbers = isset($_POST['phone_number']) ? $_POST['phone_number'] : [];
    $email = $_POST['email'];
    $created_by = $_POST['csrf_token']; // Assuming you have the c
    $pdo->beginTransaction();

try 
    {
        // Step 1: Update the draft_customers table
        $stmt = $pdo->prepare("UPDATE draft_customers SET name = :name, legal_entity_type = :legal_entity_type, industry = :industry, country = :country_id, city = :city_id, address = :address, email = :email WHERE id = :customer_id");
        $stmt->execute([
            ':name' => $name,
            ':legal_entity_type' => $legal_entity_type,
            ':industry' => $industry,
            ':country_id' => $country_id,
            ':city_id' => $city_id,
            ':address' => $address,
            ':email' => $email,
            ':customer_id' => $customer_id
        ]);

        // Step 2: Create an admin notification for the update
        $message = "Visitor with ID $created_by has updated the customer with ID $customer_id. Please review the changes.";
        $stmt = $pdo->prepare("INSERT INTO admin_notifications (customer_id, message, status) VALUES (:customer_id, :message, 'pending')");
        $stmt->execute([
            ':customer_id' => $customer_id,
            ':message' => $message
        ]);

        // Step 3: Update phone numbers in the draft_customers table
        // Delete old phone numbers
        $stmt = $pdo->prepare("DELETE FROM customer_phone_numbers WHERE customer_id = :customer_id");
        $stmt->execute([':customer_id' => $customer_id]);

        // Add new phone numbers
        foreach ($phone_numbers as $phone) 
        {
            if (!empty($phone)) { 
                $stmt = $pdo->prepare("INSERT INTO customer_phone_numbers (customer_id, phone_number) VALUES (:customer_id, :phone_number)");
                $stmt->execute([
                    ':customer_id' => $customer_id,
                    ':phone_number' => $phone
                ]);
            }
        }

        // Step 4: Commit transaction
        $pdo->commit();

        // Redirect with success message
        $_SESSION['success'] = "Customer update request has been submitted and is awaiting admin approval!";
        // echo  $_SESSION['success'];
        header('Location: ../customer/customer_list.php');
        exit();
    } 
    catch (Exception $e) 
    {
        // Rollback transaction in case of error
        $pdo->rollBack();
        $_SESSION['error'] = "Customer update failed!";
        echo $_SESSION['error'];
        // header('Location: edite_customer.php');
        exit();
    }
    
}

if (isset($_POST['add_ticket'])) {
    // بررسی داده‌های فرم
    $subject = $_POST['subject'] ?? '';
    $user_id = $_SESSION['user_id'] ?? 0;
    $ticket_text = $_POST['ticket_text'] ?? '';

    if ($user_id && !empty($subject) && !empty($ticket_text)) {
        try {
            $pdo->beginTransaction(); // شروع تراکنش

            // ثبت تیکت در جدول `tickets`
            $stmt = $pdo->prepare("INSERT INTO tickets (user_id, subject, status, created_at) VALUES (?, ?, 'open', NOW())");
            $stmt->execute([$user_id, $subject]);

            // گرفتن `id` تیکت تازه ثبت شده
            $ticket_id = $pdo->lastInsertId();

            // ثبت پیام اولیه در جدول `messages`
            $stmt = $pdo->prepare("INSERT INTO messages (ticket_id, sender, message, created_at) VALUES (?, ?, ?, NOW())");
            $stmt->execute([$ticket_id, $user_id, $ticket_text]);

            $pdo->commit(); // تایید تراکنش
            echo "✅ تیکت جدید با موفقیت ارسال شد!";
        } catch (Exception $e) {
            $pdo->rollBack(); // بازگشت تغییرات در صورت خطا
            echo "❌ خطایی رخ داد: " . $e->getMessage();
        }
    } else {
        echo "⚠ لطفاً تمامی فیلدها را پر کنید.";
    }
}
