<?php
session_start();
    error_reporting(E_ALL);
    ini_set('display_errors', 1);

//check login 
    if (!isset($_SESSION['user_id'])) 
    {
        header("Location: ../index.php");
        exit();
    }

    require_once '../php/database.php'; 
    require_once '../php/function.php';
    
      $user = new User($pdo, $_SESSION['user_id']); 
      //get the language from url 
    if (isset($_GET['lang'])) {
        $_SESSION['lang'] = $_GET['lang'];
    }
    
    //englsh is the defult language
    $lang = $_SESSION['lang'] ?? 'en'; 
    $permissions = $user->get_permissions();
 if (is_array($permissions) && !empty($permissions)) 
    {
        $user_name = $_SESSION['username'] ?? "User";
        $user_role = $user->get_role();
        $user_permissions = $user->get_permissions();
        
        $query = $pdo->prepare("SELECT timezone FROM users WHERE user_id = :user_id");
        $query->execute(['user_id' => $_SESSION['user_id']]);
        $timezone = $query->fetchColumn();
        
        if ($timezone) 
        {
            date_default_timezone_set($timezone);
        }
        
        $hour = date('H');
        $greeting = ($hour < 12) ? "Good morning" : (($hour < 18) ? "Good afternoon." : "Good evening.");

        $total_customers = 15;
        $total_orders = 8;
        $last_customer = "Ali from Tehran";
        $last_order = "#10345";
        $quotes = ["Success is not the key to happiness. Happiness is the key to success. – Albert Schweitzer",
            "The only way to do great work is to love what you do. – Steve Jobs",
            "Don't watch the clock; do what it does. Keep going. – Sam Levenson"
        ];
        $quote = $quotes[array_rand($quotes)];
        $dashboard = new Dashboard($user); 
    } 
    else
    {
        header("Location: ../index.php");
        exit();
    }


// دریافت ticket_id از URL
$ticket_id = $_GET['ticket_id'] ?? 0;

if ($ticket_id) {
    // دریافت جزئیات تیکت از دیتابیس
    $stmt = $pdo->prepare("SELECT * FROM tickets WHERE id = ?"); // 👈 تغییر `ticket_id` به `id`
    $stmt->execute([$ticket_id]);
    $ticket = $stmt->fetch(PDO::FETCH_ASSOC);


    if ($ticket) {
        // نمایش جزئیات تیکت
        echo "<h1>جزئیات تیکت</h1>";
        echo "<p><strong>موضوع:</strong> " . htmlspecialchars($ticket['subject']) . "</p>";
        echo "<p><strong>تاریخ ایجاد:</strong> " . $ticket['created_at'] . "</p>";
    } else {
        echo "تیکت با این شناسه پیدا نشد.";
    }
} else {
    echo "شناسه تیکت مشخص نشده است.";
}

// دریافت پیام‌های مربوط به این تیکت
$stmt = $pdo->prepare("SELECT sender, message, created_at FROM messages WHERE ticket_id = ? ORDER BY created_at ASC");
$stmt->execute([$ticket_id]);
$messages = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="fa">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>جزئیات تیکت</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="styles.css">
    <style>
        body {
            direction: rtl;
            font-family: Tahoma, Geneva, sans-serif;
        }

        #chat-box {
            max-width: 800px;
            margin: 20px auto;
            padding: 15px;
            border: 1px solid #ddd;
            background: #f9f9f9;
            border-radius: 10px;
            overflow-y: auto;
            max-height: 400px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }

        .message {
            padding: 12px;
            margin: 8px 0;
            border-radius: 8px;
            max-width: 80%;
            clear: both;
        }

        .my-message {
            background: #d1f7c4;
            text-align: right;
            float: right;
        }

        .support-message {
            background: #f1f1f1;
            text-align: left;
            float: left;
        }

        .message .time {
            font-size: 0.8em;
            color: #666;
            margin-top: 5px;
        }

        .message p {
            margin: 0;
        }

        textarea {
            width: 100%;
            height: 100px;
            margin-bottom: 10px;
            padding: 10px;
            border-radius: 8px;
            border: 1px solid #ddd;
        }

        button {
            width: 100%;
            padding: 10px;
            background-color: #007bff;
            color: #fff;
            border: none;
            border-radius: 8px;
            cursor: pointer;
        }

        button:hover {
            background-color: #0056b3;
        }

        .ticket-details {
            margin-bottom: 30px;
        }
    </style>
</head>
<body>

<div class="container">
    <h1 class="my-4 text-center">جزئیات تیکت</h1>

    <?php if ($ticket): ?>
        <div class="ticket-details">
            <h3>موضوع: <strong><?php echo htmlspecialchars($ticket['subject']); ?></strong></h3>
            <p><strong>تاریخ ایجاد:</strong> <?php echo $ticket['created_at']; ?></p>
        </div>
    <?php else: ?>
        <p>تیکت با این شناسه پیدا نشد.</p>
    <?php endif; ?>

    <h2 class="my-4">پیام‌ها</h2>
    <div id="chat-box">
        <?php foreach ($messages as $message): ?>
            <div class="message <?php echo ($message['sender'] == $_SESSION['username']) ? 'my-message' : 'support-message'; ?>">
                <strong><?php echo htmlspecialchars($message['sender']); ?>:</strong>
                <p><?php echo nl2br(htmlspecialchars($message['message'])); ?></p>
                <p class="time"><?php echo $message['created_at']; ?></p>
            </div>
        <?php endforeach; ?>
    </div>

    <h3 class="my-4">ارسال پیام جدید</h3>
    <form action="send_message.php" method="POST">
        <input type="hidden" name="ticket_id" value="<?php echo $ticket_id; ?>">
        <textarea name="message" required></textarea>
        <button type="submit">ارسال پیام</button>
    </form>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>

</body>
</html>

