<?php
    session_start();
    error_reporting(E_ALL);
    ini_set('display_errors', 1);

    //check login 
    if (!isset($_SESSION['user_id'])) 
    {
        header("Location: index.php");
        exit();
    }

    require_once 'database.php'; 
    require_once 'function.php'; 
    $user = new User($pdo, $_SESSION['user_id']);
    $dashboard = new Dashboard($user); 

    $stmt = $pdo->query("SELECT id, name FROM countries ORDER BY name ASC");
    $countries = $stmt->fetchAll(PDO::FETCH_ASSOC);
    $permissions = $user->get_permissions();

    if (!in_array('add_customer', $permissions)) {
        header("Location: index.php");
        exit();
    }
    
    $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard</title>
     <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css"/>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css"/>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="assets/css/style.css" />
    <style>
        .success {
            color: green;
            background-color: #d4edda;
            padding: 10px;
            border: 1px solid #c3e6cb;
            border-radius: 5px;
            margin-bottom: 15px;
        }
        .error {
            color: red;
            background-color: #f8d7da;
            padding: 10px;
            border: 1px solid #f5c6cb;
            border-radius: 5px;
            margin-bottom: 15px;
        }
    </style>
</head>
<body>
    <!-- Main content -->
    <div class="d-flex">
        <?php include("side_bar.php"); ?>
        <div class="container animate__animated animate__fadeIn mt-5 ">
            <div class="row">
                <div class="col-md-12">
                    <?php
                        if (isset($_SESSION['message'])) 
                        {
                            echo "<div id='message' class='{$_SESSION['message_type']}'>" . $_SESSION['message'] . "</div>";
                            unset($_SESSION['message']);
                            unset($_SESSION['message_type']);
                        }?>
                    <div class="aside-form">
                        <h4 class="text-center" style="font-weight:bold;color:#7a5fff">Register New Customer</h4>
                        <form action="process.php" method="POST" class="mt-5">
                            <input type="hidden" name="csrf_token" value="<?= $_SESSION['csrf_token']; ?>">
                            <input type="hidden" name="status" value="draft"> 
                            <div class="mb-3">
                                <label for="name" class="form-label">Company/Individual Name</label>
                                <input type="text" class="form-control" id="name" name="name" required>
                            </div>
    
                            <div class="mb-3">
                                <label for="legal_entity_type" class="form-label">Legal Entity Type</label>
                                <select class="form-control" id="legal_entity_type" name="legal_entity_type" required>
                                    <option value="Corporate">Corporate</option>
                                    <option value="Individual">Individual</option>
                                </select>
                            </div>
    
                            <div class="mb-3">
                                <label for="industry" class="form-label">Industry</label>
                                <input type="text" class="form-control" id="industry" name="industry" required>
                            </div>
    
                            <div class="mb-3">
                                <label for="country" class="form-label">Country</label>
                                <select class="form-control" id="country" name="country" required>
                                    <option value="">Select Country</option>
                                    <?php foreach ($countries as $country): ?>
                                        <option value="<?php echo $country['id']; ?>"><?php echo htmlspecialchars($country['name']); ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
    
                            <div class="mb-3">
                                <label for="city" class="form-label">City</label>
                                <select class="form-control" id="city" name="city" required>
                                    <option value="">Select City</option>
                                </select>
                            </div>
    
                            <div class="mb-3">
                                <label for="address" class="form-label">Address</label>
                                <input type="text" class="form-control" id="address" name="address" required>
                            </div>
    
                            <div class="mb-3">
                                <label for="phone_number" class="form-label">Phone Number</label>
                                <div class="phone-field">
                                    <input type="text" name="phone_number[]" id="phone_number"  class="phone-input form-control" placeholder="">
                                </div>
                                <div id="phone-container"></div>
                                <button class="btn" type="button" id="add-phone">+ add phone number</button>
                            </div>
    
                            <div class="mb-3">
                                <label for="email" class="form-label">Email</label>
                                <input type="email" class="form-control" id="email" name="email" required>
                            </div>
    
                            <button value="1" type="submit" name="add_customer" class="btn login-btn ">Add Customer</button>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        //add phone number input 
        document.getElementById("add-phone").addEventListener("click", function () {
            let container = document.getElementById("phone-container");
            let newInput = document.createElement("div");
            newInput.classList.add("phone-field");
    
            //hide new input
            newInput.style.opacity = "0";
            newInput.style.transform = "translateY(-20px)";
            newInput.style.transition = "opacity 0.5s ease-out, transform 0.5s ease-out";
    
            newInput.innerHTML = `
                <input type="text" name="phone_number[]" id="phone_number"  class="phone-input form-control mt-2" placeholder="">
                <button type="button" class="remove-phone btn btn-danger btn-sm mt-2 ms-2">❌</button>
            `;
    
            //hide button
            this.style.opacity = "0"; 
            this.style.transition = "opacity 0.5s ease-out"; 
            setTimeout(() => {
                this.style.opacity = "1"; 
            }, 500); 
        
            //add container to form 
            container.appendChild(newInput);
        
            setTimeout(() => {
                newInput.style.opacity = "1";
                newInput.style.transform = "translateY(0)";
            }, 10);
        });
    
        //delete phone numbers
        document.addEventListener("click", function (e) {
            if (e.target.classList.contains("remove-phone")) {
                let phoneField = e.target.parentElement;
                phoneField.style.opacity = "0";
                phoneField.style.transform = "translateY(-10px)";
                setTimeout(() => {
                    phoneField.remove();
                }, 300); 
            }
        });
        //show contries
        $(document).ready(function () {
            $('#country').change(function () {
                var country_id = $(this).val();
                if (country_id != "") {
                    $.ajax({
                        url: 'get_cities.php',
                        method: 'POST',
                        data: { country_id: country_id },
                        success: function (response) {
                            $('#city').html(response);
                        }
                    });
                } else {
                    $('#city').html('<option value="">Select City</option>');
                }
            });
        });
        
        //error and success alert
        window.onload = function() {
            var messageElement = document.getElementById('message');
            if (messageElement) {
                setTimeout(function() {
                    messageElement.style.display = 'none';
                }, 5000); 
            }
        }
    </script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
