<?php
session_start();
error_reporting(E_ALL);
ini_set('display_errors', 1);

// بررسی لاگین
if (!isset($_SESSION['user_id'])) {
    echo "You are not logged in.";
    exit();
}

require_once 'database.php'; // اتصال به دیتابیس
require_once 'function.php'; // فرض بر این است که این فایل کلاسی برای دسترسی‌ها دارد
$user = new User($pdo, $_SESSION['user_id']); // ساخت شیء User

$dashboard = new Dashboard($user);  // ساخت شیء Dashboard با ارسال شیء User به سازنده آن
// دریافت لیست کشورها از دیتابیس
$stmt = $pdo->query("SELECT id, name FROM countries ORDER BY name ASC");
$countries = $stmt->fetchAll(PDO::FETCH_ASSOC);
$permissions = $user->get_permissions(); // گرفتن دسترسی‌ها از متد `get_permissions`

if (!in_array('add_customer', $permissions)) {
    echo "You do not have permission to add customers.";
    exit();
}

$successMessage = ''; // Initialize the variable
$user_id = $_SESSION['user_id'];
$customer_id = $_GET['id'] ?? null;
// بررسی اینکه این مشتری متعلق به ویزیتور هست
$stmt = $pdo->prepare("SELECT * FROM draft_customers WHERE id = ? AND created_by = ?");
$stmt->execute([$customer_id, $user_id]);
$customer = $stmt->fetch(PDO::FETCH_ASSOC);
$_SESSION['csrf_token'] = bin2hex(random_bytes(32));
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css"/>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css"/>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="assets/css/style.css" />
    <style>
        /* استایل برای پیغام‌های موفقیت */
        .success {
            color: green;
            background-color: #d4edda;
            padding: 10px;
            border: 1px solid #c3e6cb;
            border-radius: 5px;
            margin-bottom: 15px;
        }

        /* استایل برای پیغام‌های خطا */
        .error {
            color: red;
            background-color: #f8d7da;
            padding: 10px;
            border: 1px solid #f5c6cb;
            border-radius: 5px;
            margin-bottom: 15px;
        }
    </style>
</head>
<body>

<!-- Main content -->
<div class="d-flex">
    <?php include("side_bar.php"); ?>
    <div class="container animate__animated animate__fadeIn mt-5">
        <div class="row">
            <div class="col-md-12">
                <?php if (!empty($successMessage)): ?>
                    <script type="text/javascript">
                        alert("<?php echo $successMessage; ?>");
                    </script>
                <?php endif; 
                // اگر پیامی در session وجود دارد
                if (isset($_SESSION['message'])) {
                    // نمایش پیام
                    echo "<div id='message' class='{$_SESSION['message_type']}'>" . $_SESSION['message'] . "</div>";
                
                    // پاک کردن پیام بعد از نمایش
                    unset($_SESSION['message']);
                    unset($_SESSION['message_type']);
                }?>
                <div class="aside-form">
                    <h4 class="text-center" style="font-weight:bold;color:#7a5fff">Update Customer</h4>
                    <form action="process.php" method="POST" class="mt-5">
                        <input type="hidden" name="customer_id" value="<?= htmlspecialchars($customer['id']) ?>">
                        <input type="hidden" name="csrf_token" value="<?= $_SESSION['csrf_token']; ?>">
                        <div class="mb-3">
                            <label for="name" class="form-label">Company/Individual Name</label>
                            <input type="text"  value="<?= htmlspecialchars($customer['name']) ?>" class="form-control" id="name" name="name" required>
                        </div>

                            <div class="mb-3">
                            <label for="legal_entity_type" class="form-label">Legal Entity Type</label>
                            <select class="form-control" id="legal_entity_type" name="legal_entity_type" required>
                                <option value="Corporate" <?= ($customer['legal_entity_type'] == 'Corporate') ? 'selected' : ''; ?>>Corporate</option>
                                <option value="Individual" <?= ($customer['legal_entity_type'] == 'Individual') ? 'selected' : ''; ?>>Individual</option>
                            </select>
                        </div>


                        <div class="mb-3">
                            <label for="industry" class="form-label">Industry</label>
                            <input type="text" class="form-control" value="<?= htmlspecialchars($customer['industry']) ?>" id="industry" name="industry" required>
                        </div>

                       <div class="mb-3">
    <label for="country" class="form-label">Country</label>
    <select class="form-control" id="country" name="country_name" required>
        <option value="">انتخاب کشور</option>
        <?php
        // دریافت تمام کشورهای موجود
        $stmt = $pdo->query("SELECT id, name FROM countries");
        $countries = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // دریافت اطلاعات مشتری
        $stmt = $pdo->prepare("SELECT c.*, co.name as country_name
            FROM customers c
            LEFT JOIN countries co ON c.country = co.id
            WHERE c.id = :customer_id");
        $stmt->execute(['customer_id' => $customer_id]);
        $customer_result = $stmt->fetch(PDO::FETCH_ASSOC);

        // نمایش لیست کشورها
        foreach ($countries as $country) {
            $selected = ($customer_result['country_name'] == $country['name']) ? 'selected' : '';
            echo "<option value='{$country['id']}' $selected>{$country['name']}</option>";
        }
        ?>
    </select>
</div>

<div class="mb-3">
    <label for="city" class="form-label">City</label>
    <select class="form-control" id="city" name="city" required>
        <option value="">انتخاب شهر</option>
        <?php
        // دریافت شهرهای مربوط به کشور انتخاب شده در ابتدای بارگذاری
        $country_id = $customer_result['country'];  // فرض می‌کنیم که $customer_result['country'] شامل ID کشور است

        // دریافت تمام شهرهای کشور
        $stmt = $pdo->prepare("SELECT id, name FROM cities WHERE country_id = :country_id");
        $stmt->execute(['country_id' => $country_id]);
        $cities = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // نمایش شهرهای مربوط به کشور
        foreach ($cities as $city) {
            $selected = ($customer_result['city'] == $city['id']) ? 'selected' : '';
            echo "<option value='{$city['id']}' $selected>{$city['name']}</option>";
        }
        ?>
    </select>
</div>



                        <div class="mb-3">
                            <label for="address" class="form-label">Address</label>
                            <input type="text" value="<?= htmlspecialchars($customer['address']) ?>" class="form-control" id="address" name="address" required>
                        </div>

                        <?php
                        // دریافت شماره تلفن‌ها برای مشتری خاص
                        $stmt = $pdo->prepare("SELECT id, phone_number FROM customer_phone_numbers WHERE customer_id = ?");
                        $stmt->execute([$customer['id']]);
                        $phone_numbers = $stmt->fetchAll(PDO::FETCH_ASSOC);
                        ?>
                        <div class="mb-3">
    <label for="phone_number" class="form-label">Phone Numbers</label>
    <div class="phone-field">
        <?php 
        // برای هر شماره تلفن یک input و دکمه حذف اضافه می‌کنیم
        foreach ($phone_numbers as $phone) { ?>
            <div class="phone-item">
                <input type="text" value="<?= htmlspecialchars($phone['phone_number']) ?>" name="phone_number[]" class="phone-input form-control mt-2" placeholder="Phone Number">
                <button type="button" class="remove-phone-btn btn btn-danger btn-sm mt-2 ms-2">Remove</button>
            </div>
        <?php } ?>
    </div>
    <div id="phone-container"></div>
    <button class="btn" type="button" id="add-phone">+ Add phone number</button>
</div>


                        <div class="mb-3">
                            <label for="email"  class="form-label">Email</label>
                            <input type="email" value="<?= htmlspecialchars($customer['email']) ?>" class="form-control" id="email" name="email" required>
                        </div>

                        <button value="1" type="submit" name="update_customer" class="btn login-btn ">Update Customer</button>
                    </form>
                </div>
                
            </div>
        </div>
    </div>
</div>

<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script>
    // document.getElementById("add-phone").addEventListener("click", function () {
    //     let container = document.getElementById("phone-container");
    //     let newInput = document.createElement("div");
    //     newInput.classList.add("phone-field");

    //     // فرم جدید رو پنهان می‌کنیم
    //     newInput.style.opacity = "0";
    //     newInput.style.transform = "translateY(-20px)";
    //     newInput.style.transition = "opacity 0.5s ease-out, transform 0.5s ease-out";

    //     newInput.innerHTML = `
    //         <input type="text" name="phone_number[]" id="phone_number"  class="phone-input form-control mt-2" placeholder="شماره تلفن">
    //         <button type="button" class="remove-phone btn btn-danger btn-sm mt-2 ms-2">❌</button>
    //     `;

    //     // ابتدا دکمه رو پنهان می‌کنیم
    //     this.style.opacity = "0"; // محو شدن دکمه
    //     this.style.transition = "opacity 0.5s ease-out"; // انیمیشن محو شدن دکمه
    //     setTimeout(() => {
    //         this.style.opacity = "1"; // دکمه بعد از انیمیشن دوباره ظاهر بشه
    //     }, 500); // 500 میلی‌ثانیه بعد از محو شدن دکمه

    //     // فرم رو به container اضافه می‌کنیم
    //     container.appendChild(newInput);

    //     // بعد از 500 میلی‌ثانیه (زمان انیمیشن فرم)، فرم رو به حالت قابل مشاهده میاریم
    //     setTimeout(() => {
    //         newInput.style.opacity = "1";
    //         newInput.style.transform = "translateY(0)";
    //     }, 10);
    // });

    // حذف شماره‌ها با انیمیشن نرم
    document.addEventListener("click", function (e) {
        if (e.target.classList.contains("remove-phone")) {
            let phoneField = e.target.parentElement;
            phoneField.style.opacity = "0";
            phoneField.style.transform = "translateY(-10px)";
            setTimeout(() => {
                phoneField.remove();
            }, 300); // 300 میلی‌ثانیه بعد از انیمیشن
        }
    });

    $(document).ready(function () {
    $('#country').change(function () {
        var country_id = $(this).val();
        console.log("Selected country_id: " + country_id); // برای دیباگ کردن country_id

        if (country_id != "") {
            $.ajax({
                url: 'get_cities.php',
                method: 'POST',
                data: { country_id: country_id },
                success: function (data) {
                    console.log("Cities data: " + data); // بررسی داده‌های برگشتی از سرور
                    $('#city').html(data); // جایگزینی محتویات select
                },
                error: function (xhr, status, error) {
                    console.error("AJAX Error: " + error);
                }
            });
        } else {
            $('#city').html('<option value="">Select City</option>');
        }
    });
});
$(document).ready(function () {
    // اضافه کردن شماره تلفن جدید با استفاده از jQuery
    $('#add-phone').click(function () {
        var newPhoneInput = `
            <div class="phone-item">
                <input type="text" name="phone_number[]" class="phone-input form-control mt-2" placeholder="Phone Number">
                <button type="button" class="remove-phone-btn btn btn-danger btn-sm mt-2 ms-2">Remove</button>
            </div>
        `;
        $('#phone-container').append(newPhoneInput);  // اضافه کردن به container
    });

    // حذف شماره تلفن
    $(document).on('click', '.remove-phone-btn', function () {
        $(this).closest('.phone-item').fadeOut(300, function () {
            $(this).remove(); // حذف از DOM پس از انیمیشن
        });
    });
});

// $(document).ready(function () {
//     // حذف شماره تلفن
//     $(document).on('click', '.remove-phone-btn', function () {
//         var phoneId = $(this).data('phone-id'); // دریافت شناسه شماره تلفن از data-phone-id

//         // حذف از رابط کاربری
//         $(this).closest('.phone-item').fadeOut(300, function () {
//             $(this).remove(); // حذف از DOM پس از انیمیشن
//         });

//         // اگر نیاز دارید که شماره تلفن از دیتابیس حذف بشه، می‌توانید درخواست AJAX ارسال کنید
//         if (phoneId) {
//             $.ajax({
//                 url: 'delete_phone.php',  // مسیر حذف شماره تلفن
//                 method: 'POST',
//                 data: { phone_id: phoneId },
//                 success: function (response) {
//                     console.log('Phone number deleted successfully');
//                     // می‌توانید پیام موفقیت یا خطا نشان دهید در صورت نیاز
//                 },
//                 error: function (xhr, status, error) {
//                     console.error('Error deleting phone number: ' + error);
//                 }
//             });
//         }
//     });

//     // اضافه کردن شماره تلفن جدید
//     $('#add-phone').click(function () {
//         var newPhoneInput = `
//             <div class="phone-item">
//                 <input type="text" name="phone_number[]" class="phone-input form-control" placeholder="Phone Number">
//                 <button type="button" class="remove-phone-btn btn btn-danger">Remove</button>
//             </div>
//         `;
//         $('#phone-container').append(newPhoneInput);
//     });
// });

</script>


<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
