<?php
class User {
    private $pdo;  // تغییر نام متغیر به `$pdo`
    private $user_id;
    private $permissions = [];
    private $role; // اضافه کردن متغیر برای ذخیره نقش کاربر


   public function __construct($pdo, $user_id) {
        $this->pdo = $pdo;
        $this->user_id = $user_id;
        $this->load_permissions();
        $this->load_role(); // بارگذاری نقش هنگام ساخت شیء
    }

    public function validate_user($username, $password) {
        // اصلاح: استفاده از `$pdo` به جای `$conn`
        $query = "SELECT * FROM users WHERE name = :username";
        $stmt = $this->pdo->prepare($query);
        $stmt->bindParam(":username", $username);
        $stmt->execute();

        $user = $stmt->fetch(PDO::FETCH_ASSOC);

        // بررسی صحت پسورد با استفاده از password_verify
        if ($user && password_verify($password, $user['password'])) {
            return $user;
        }

        return false;
    }

    private function load_permissions() {
    $query = "
        SELECT roles.role_name AS role_name, permissions.permission_name AS permission_name
        FROM users
        JOIN user_roles ON users.user_id = user_roles.user_id
        JOIN roles ON user_roles.role_id = roles.role_id
        JOIN role_permissions ON roles.role_id = role_permissions.role_id
        JOIN permissions ON role_permissions.permission_id = permissions.permission_id
        WHERE users.user_id = :user_id
    ";
    $stmt = $this->pdo->prepare($query);
    $stmt->bindParam(':user_id', $this->user_id);
    $stmt->execute();

    $permissions_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // چک کردن اینکه آیا هیچ داده‌ای برنگشته است
    if ($permissions_data) {
        foreach ($permissions_data as $permission) {
            $this->permissions[] = $permission['permission_name'];
        }
    } else {
        // نمایش خطای مناسب در صورت عدم وجود دسترسی‌ها
        echo "No permissions found for user ID: " . $this->user_id;
    }
}

    private function load_role() {
        $query = "
            SELECT roles.role_name
            FROM users
            JOIN user_roles ON users.user_id = user_roles.user_id
            JOIN roles ON user_roles.role_id = roles.role_id
            WHERE users.user_id = :user_id
        ";
        $stmt = $this->pdo->prepare($query);
        $stmt->bindParam(':user_id', $this->user_id);
        $stmt->execute();

        $role_data = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($role_data) {
            $this->role = $role_data['role_name'];
        } else {
            $this->role = 'No Role'; // در صورتی که نقش یافت نشد
        }
    }

    // بررسی دسترسی به یک بخش خاص
    public function has_permission($permission) {
        return in_array($permission, $this->permissions);
    }

    // گرفتن تمام دسترسی‌ها
    public function get_permissions() {
        return $this->permissions;
    }
     // گرفتن نقش کاربر
    public function get_role() {
        return $this->role;
    }
}

class Dashboard {
    private $user;

    // سازنده کلاس که شیء User را دریافت می‌کند
    public function __construct($user) {
        $this->user = $user;
    }

    public function display_links() {
        $links = [
            'view_dashboard' => 'Dashboard',
            'manage_users' => 'Manage Users',
            'manage_roles' => 'Manage Roles',
            'manage_permissions' => 'Manage Permissions',
            'manage_orders' => 'Manage Orders',
            'view_reports' => 'View Reports',
            'add_customer' => 'add customer',
            'add_materials' => 'add materials',
            'view_raw_materials' => 'view raw materials',
            'manage_stock' => 'manage stock',
            'manage_suppliers' => 'manage suppliers',
            'record_purchases' => 'record purchases',
            'customer_list' => 'customers list',
            'customers_notifications' => 'customers notifications',
            'create_ticket' => 'create ticket'
        ];

        foreach ($links as $permission => $link_name) {
            if ($this->user->has_permission($permission)) {
                echo "<a href='{$permission}.php'>{$link_name}</a><br>";
            }
        }
    }

    // نمایش داشبورد
    public function display_dashboard() {
        $this->display_links();
    }
}

class Customer {
    private $pdo;
    
    // سازنده برای دریافت اتصال به پایگاه داده
    public function __construct($pdo) {
        $this->pdo = $pdo;
    }

    // تابع برای ثبت مشتری جدید در دیتابیس
    public function add_customer($name, $legal_entity_type, $industry, $country, $city, $address, $phone_number, $email, $website_url, $created_by) {
        $sql = "INSERT INTO customers (name, legal_entity_type, industry, country, city, address, phone_number, email, website_url, created_by)
                VALUES (:name, :legal_entity_type, :industry, :country, :city, :address, :phone_number, :email, :website_url, :created_by)";

        $stmt = $this->pdo->prepare($sql);
        $stmt->execute([
            ':name' => $name,
            ':legal_entity_type' => $legal_entity_type,
            ':industry' => $industry,
            ':country' => $country,
            ':city' => $city,
            ':address' => $address,
            ':phone_number' => $phone_number,
            ':email' => $email,
            ':website_url' => $website_url,
            ':created_by' => $created_by
        ]);

        return $this->pdo->lastInsertId(); // برگرداندن ID مشتری ثبت‌شده
    }

    // تابع برای دریافت لیست مشتریان (با توجه به ویزیتور لاگین شده)
    public function get_customers_by_visitor($visitor_id) {
        $sql = "SELECT * FROM customers WHERE created_by = :created_by";
        $stmt = $this->pdo->prepare($sql);
        $stmt->execute([':created_by' => $visitor_id]);
        
        return $stmt->fetchAll(PDO::FETCH_ASSOC); // بازگرداندن نتایج به صورت آرایه
    }

    // تابع برای دریافت اطلاعات یک مشتری خاص
    public function get_customer_by_id($customer_id) {
        $sql = "SELECT * FROM customers WHERE id = :id";
        $stmt = $this->pdo->prepare($sql);
        $stmt->execute([':id' => $customer_id]);
        
        return $stmt->fetch(PDO::FETCH_ASSOC); // بازگرداندن نتیجه به صورت آرایه
    }

    // تابع برای به‌روزرسانی اطلاعات مشتری
    public function update_customer($id, $name, $legal_entity_type, $industry, $country, $city, $address, $phone_number, $email, $website_url) {
        $sql = "UPDATE customers SET name = :name, legal_entity_type = :legal_entity_type, industry = :industry,
                country = :country, city = :city, address = :address, phone_number = :phone_number, email = :email, website_url = :website_url
                WHERE id = :id";

        $stmt = $this->pdo->prepare($sql);
        $stmt->execute([
            ':id' => $id,
            ':name' => $name,
            ':legal_entity_type' => $legal_entity_type,
            ':industry' => $industry,
            ':country' => $country,
            ':city' => $city,
            ':address' => $address,
            ':phone_number' => $phone_number,
            ':email' => $email,
            ':website_url' => $website_url
        ]);
    }

    // تابع برای حذف مشتری از دیتابیس
    public function delete_customer($id) {
        $sql = "DELETE FROM customers WHERE id = :id";
        $stmt = $this->pdo->prepare($sql);
        $stmt->execute([':id' => $id]);
    }
}


