<?php
session_start();
error_reporting(E_ALL);
ini_set('display_errors', 1);

// بررسی لاگین
if (!isset($_SESSION['user_id'])) {
   header("Location: index.php");
    exit();
}

require_once 'database.php'; // اتصال به دیتابیس
require_once 'function.php'; // کلاس User

// ایجاد شیء User و دریافت دسترسی‌ها
$user = new User($pdo, $_SESSION['user_id']); // استفاده از $pdo به جای $conn
$permissions = $user->get_permissions();

// چک کردن اینکه آیا $permissions مقداردهی شده است
if (is_array($permissions) && !empty($permissions)) {
    // اکنون می‌توانید از $permissions استفاده کنید
    $user_name = $_SESSION['username'] ?? "User";
    $user_role = $user->get_role(); // دریافت نقش کاربر
    $user_permissions = $user->get_permissions(); // دریافت دسترسی‌ها
    
    // دریافت تایم زون کاربر از دیتابیس
    $query = $pdo->prepare("SELECT timezone FROM users WHERE user_id = :user_id");
    $query->execute(['user_id' => $_SESSION['user_id']]);
    $timezone = $query->fetchColumn();

    // تنظیم تایم زون PHP با استفاده از تایم زون کاربر
    if ($timezone) {
        date_default_timezone_set($timezone);
    }

    $hour = date('H');
    $greeting = ($hour < 12) ? "Good morning" : (($hour < 18) ? "Good afternoon" : "Good evening");

    $total_customers = 15;
    $total_orders = 8;
    $last_customer = "Ali from Tehran";
    $last_order = "#10345";
    $quotes = [
        "Success is not the key to happiness. Happiness is the key to success. – Albert Schweitzer",
        "The only way to do great work is to love what you do. – Steve Jobs",
        "Don’t watch the clock; do what it does. Keep going. – Sam Levenson"
    ];
    $quote = $quotes[array_rand($quotes)];

    // ایجاد شیء Dashboard و نمایش آن
    $dashboard = new Dashboard($user); // ایجاد شیء Dashboard با استفاده از شیء User
    
} else {
    echo "No permissions assigned to the user.";
    exit(); // اگر دسترسی‌ها یافت نشد، دیگر به داشبورد ادامه نمی‌دهیم
}
?>



<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard</title>
    
    
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css"/>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css"/>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="assets/css/style.css" />

</head>
<body>

<!-- Sidebar -->
<div class="d-flex">
    <?php include("side_bar.php"); ?>
    <div class="dashboard-container animate__animated animate__fadeIn">
        <div class="container mt-4">
    <h2>ثبت ورود مواد اولیه</h2>
    <form id="addStockForm">
        <div class="mb-3">
            <label>انتخاب ماده اولیه:</label>
            <select id="material_id" class="form-control"></select>
        </div>
        <div class="mb-3">
            <label>انتخاب تأمین‌کننده:</label>
            <select id="supplier_id" class="form-control"></select>
        </div>
        <div class="mb-3">
            <label>مقدار خریداری‌شده:</label>
            <input type="number" id="quantity" class="form-control">
        </div>
        <div class="mb-3">
            <label>قیمت خرید:</label>
            <input type="number" id="price" class="form-control">
        </div>
        <button type="submit" class="btn btn-success">ثبت ورود</button>
    </form>
</div>

<script>
$(document).ready(function() {
    // گرفتن لیست مواد اولیه
    $.get('getRawMaterials.php', function(data) {
        let materials = JSON.parse(data);
        let options = '<option value="">انتخاب کنید</option>';
        materials.forEach(m => {
            options += `<option value="${m.id}">${m.name}</option>`;
        });
        $('#material_id').html(options);
    });

    // گرفتن لیست تأمین‌کنندگان
    $.get('getSuppliers.php', function(data) {
        let suppliers = JSON.parse(data);
        let options = '<option value="">انتخاب کنید</option>';
        suppliers.forEach(s => {
            options += `<option value="${s.id}">${s.name}</option>`;
        });
        $('#supplier_id').html(options);
    });

    // ارسال فرم به `addStock.php`
    $('#addStockForm').submit(function(e) {
        e.preventDefault();
        let formData = {
            material_id: $('#material_id').val(),
            supplier_id: $('#supplier_id').val(),
            quantity: $('#quantity').val(),
            price: $('#price').val()
        };
        $.post('addStock.php', formData, function(response) {
            let res = JSON.parse(response);
            if (res.status === "success") {
                alert("ورود مواد اولیه ثبت شد!");
                location.reload();
            } else {
                alert("خطا در ثبت!");
            }
        });
    });
});
</script>


        
    
</div>
    <!-- Main content -->
    
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>