<?php
session_start();
error_reporting(E_ALL);
ini_set('display_errors', 1);

// بررسی لاگین
if (!isset($_SESSION['user_id'])) {
   header("Location: index.php");
    exit();
}

require_once 'database.php'; // اتصال به دیتابیس
require_once 'function.php'; // کلاس User

// ایجاد شیء User و دریافت دسترسی‌ها
$user = new User($pdo, $_SESSION['user_id']); // استفاده از $pdo به جای $conn
$permissions = $user->get_permissions();

// چک کردن اینکه آیا $permissions مقداردهی شده است
if (is_array($permissions) && !empty($permissions)) {
    // اکنون می‌توانید از $permissions استفاده کنید
    $user_name = $_SESSION['username'] ?? "User";
    $user_role = $user->get_role(); // دریافت نقش کاربر
    $user_permissions = $user->get_permissions(); // دریافت دسترسی‌ها
    
    // دریافت تایم زون کاربر از دیتابیس
    $query = $pdo->prepare("SELECT timezone FROM users WHERE user_id = :user_id");
    $query->execute(['user_id' => $_SESSION['user_id']]);
    $timezone = $query->fetchColumn();

    // تنظیم تایم زون PHP با استفاده از تایم زون کاربر
    if ($timezone) {
        date_default_timezone_set($timezone);
    }

    $hour = date('H');
    $greeting = ($hour < 12) ? "Good morning" : (($hour < 18) ? "Good afternoon" : "Good evening");

    $total_customers = 15;
    $total_orders = 8;
    $last_customer = "Ali from Tehran";
    $last_order = "#10345";
    $quotes = [
        "Success is not the key to happiness. Happiness is the key to success. – Albert Schweitzer",
        "The only way to do great work is to love what you do. – Steve Jobs",
        "Don’t watch the clock; do what it does. Keep going. – Sam Levenson"
    ];
    $quote = $quotes[array_rand($quotes)];

    // ایجاد شیء Dashboard و نمایش آن
    $dashboard = new Dashboard($user); // ایجاد شیء Dashboard با استفاده از شیء User
    
} else {
    echo "No permissions assigned to the user.";
    exit(); // اگر دسترسی‌ها یافت نشد، دیگر به داشبورد ادامه نمی‌دهیم
}
?>



<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard</title>
    
    
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css"/>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css"/>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="assets/css/style.css" />
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<style>
    .container {
        padding-top: 30px;
    }

    h2 {
        font-size: 1.8rem;
        font-weight: bold;
        color: #333;
    }

    .table th, .table td {
        text-align: center;
        vertical-align: middle;
    }
    .btn-primary {
        background-color: #50216f;
        border: 1px solid #50216f;
    }

    .btn-primary:hover {
        background-color: #af8ec6;
        border-color: #af8ec6;
    }
</style>
</head>
<body>

<!-- Sidebar -->
<div class="d-flex">
    <?php include("side_bar.php"); ?>
    <div class="container animate__animated animate__fadeIn mt-5">
        <div class="row">
            <div class="col-md-12">
                <h2 class="mb-4" style="font-weight:bold;color:#7a5fff">Raw Materials Management</h2>
                <table class="table  table-bordered table-hover">
                    <thead class="table-light">
                        <tr>
                            <th style="font-weight:bold;color:#50216f">Material Name</th>
                            <th style="font-weight:bold;color:#50216f">Unit</th>
                            <th style="font-weight:bold;color:#50216f">Stock</th>
                            <th style="font-weight:bold;color:#50216f">Minimum Stock Level</th>
                            <th style="font-weight:bold;color:#50216f">Status</th>
                            <th style="font-weight:bold;color:#50216f">Actions</th>
                        </tr>
                    </thead>
                    <tbody id="materialsTable">
                        <!-- Data will be dynamically loaded here -->
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>
<!-- Modal for Register Entry -->
<div class="modal fade" id="entryModal" tabindex="-1" aria-labelledby="entryModalLabel" aria-hidden="true">
  <div class="modal-dialog">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="entryModalLabel">Register Material Entry</h5>
        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
      </div>
      <div class="modal-body">
        <form id="entryForm" method="post">
          <input type="hidden" id="materialName" name="materialName">
          <div class="mb-3">
            <label for="entryAmount" class="form-label">Enter Quantity</label>
            <input type="number" class="form-control" id="entryAmount" name="entryAmount" min="1" required>
          </div>
          <button type="submit" class="btn btn-success">Save Entry</button>
        </form>
      </div>
    </div>
  </div>
</div>
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
$(document).ready(function() {
    // دریافت داده‌های مواد خام
    
      

    $.get('getRawMaterials.php', function(data) {
        console.log(data);
        try {
            let materials = JSON.parse(data);
            let rows = '';
            materials.forEach(material => {
                let status = material.low_stock ? '<span class="text-danger">Low Stock !</span>' : '<span class="text-success">In Stock</span>';
                rows += `<tr>
                            <td>${material.name}</td>
                            <td>${material.unit}</td>
                            <td>${material.stock}</td>
                            <td>${material.min_stock_level}</td>
                            <td>${status}</td>
                            <td>
                                <button class="btn btn-primary btn-entry" data-name="${material.name}">Register Entry</button>
                                <button class="btn btn-primary">Register Exit</button>
                            </td>
                        </tr>`;
            });
            $('#materialsTable').html(rows);
        } catch (e) {
            cconsole.error('Error parsing JSON:', e);
        }
    });

    // Open Modal on "Register Entry" Click
    $(document).on('click', '.btn-entry', function() {
        let materialName = $(this).data('name'); // گرفتن نام ماده
        $('#materialName').val(materialName); // ذخیره داخل فرم
        $('#entryModal').modal('show'); // نمایش مودال
    });

    $(document).on('submit', '#entryForm', function(e) {
    e.preventDefault(); // جلوگیری از ارسال پیش‌فرض فرم
    
    let formData = $(this).serialize(); // جمع‌آوری داده‌های فرم
    console.log(formData); // نمایش داده‌های فرم در کنسول
    
    $.post('updateStock.php', formData, function(response) {
        console.log(response); // نمایش پاسخ سرور
        alert(response.message); // نمایش پیام دریافتی از سرور
        $('#entryModal').modal('hide'); // بستن مودال
        location.reload(); // رفرش صفحه
    }, 'json')
    .fail(function(xhr, status, error) {
        console.error("Error:", error);
        alert("Something went wrong!");
    });
});

});
</script>

        
    
</div>
    <!-- Main content -->
    
</div>

</body>
</html>